@@ -3,6 +3,9 @@
 
 // -> ORG/womanloop.cpp
 
+size_t g_caseIdx;           // -> loop.ih       if (caseIdx > 24842)
+size_t g_err = 4726;
+
 void Loop::genCases(size_t iter, size_t nCases)
 {
     CSVTable dataTable = headerData(iter);
@@ -12,22 +15,21 @@ void Loop::genCases(size_t iter, size_t nCases)
                                         // perform 'nCases' simulations
     for (size_t caseIdx = 0; caseIdx != nCases; ++caseIdx)
     {
-        //xerr("caseInit " << caseIdx << ' ' << nCases);
+        g_caseIdx = caseIdx;
+
+        g_log.caseIdx(caseIdx);
         caseInit();
 
-        //xerr("preScreen");
         preScreen();        // no action unless screening rounds are specified
 
-        //xerr("screening");
         screening();        // same
 
-        //xerr("postScreen");
         postScreen();
 
         d_sumDeathAge += d_deathAge;
         d_totalCost += d_caseCost;
 
-        //xerr("write data");
+//xerr("write data");
         if (dataTable.stream() and (showAll or caseIdx + 1 == nCases))
             writeData(dataTable, caseIdx);
     }
@@ -39,8 +41,3 @@ void Loop::genCases(size_t iter, size_t nCases)
 // woman has died or not. This test is superfluous because if the woman enters
 // postScreen with status PRESENT then in postScreen the status either changes
 // to LEFT_POST or TUMOR_POST.
-
-
-
-
-
