@@ -8,11 +8,6 @@ inline uint16_t Screening::nRounds() const
     return d_roundVect.size();
 }
 
-inline double Screening::roundAge(size_t idx) const
-{
-    return d_roundVect[idx].age();
-}
-
 inline Round const &Screening::round(size_t idx) const
 {
     return d_roundVect[idx];
