@@ -8,10 +8,23 @@
 // "Supplementary's" tables S3 and S4 are loaded by Survival. and the table
 // S4's a..d values are obtained from Survival::op[0..3], see survival.h
 
+extern size_t g_caseIdx;
+extern size_t g_err;
+
 double Tumor::functionQ(double years) const
 {
-xerr("d_survival[0] " << &d_survival[0]);    
-xerr("d_survival[1] " << &d_survival[1]);    
+//    auto hit =                  // tumorinfo.survival?
+//        [&]()
+//        {
+//            return
+//                   g_caseIdx >= g_err;
+//        };
+
+//if (hit())
+//{
+//xerr("d_survival[1] " << &d_survival[1]  << ' ' << d_survival[1].value());
+//xerr("d_survival[0] " << &d_survival[0]);
+//}
 
     return d_survival[0].value() * pow(years, d_survival[1].value());
 }
