@@ -3,6 +3,8 @@
 
 void Tumor::reset()
 {
+    g_log << "  Tumor::reset\n";
+
     d_found = false;
     d_interval = false;
 
@@ -33,30 +35,35 @@ void Tumor::reset()
 
     AgeGroupVSD const &group = d_growth.ageGroupVSD(idx);
 
-//xerr("idx: " << idx << ", value: " << group.value() << ", stdev = " <<
-//group.stdDev());
-
     d_doublingDays = random.logNormal(group.value(), group.stdDev());
 
-//xerr("doublingdays: " << d_doublingDays);
-
 
     d_doublingYears = d_doublingDays / N_YEARDAYS;
 
-    double selfDetectDiam = random.logNormal(d_growth.selfMu().value(), 
+    double selfDetectDiam = random.logNormal(d_growth.selfMu().value(),
                                              d_growth.selfSigma());
 
     d_prePeriod =   d_doublingDays *
                     log(
-                        volume(selfDetectDiam) / 
+                        volume(selfDetectDiam) /
                         volume(d_growth.start())
                     ) * s_log2YearInv;
 
     d_detectableAge = d_selfDetectAge - d_prePeriod;
+
+    g_log << "\nTUMOR RESET:\n"
+             "  selfDetectDiam = " << selfDetectDiam << "\n"
+             "  selfDetectAge =  " << d_selfDetectAge << "\n"
+             "  growth start =   " << d_growth.start() << "\n"
+             "  p(survival) =    " << d_pSurvival << "\n"
+             "  preperiod =      " << d_prePeriod << "\n"
+             "  detectableAge = " << d_detectableAge << '\n';
+
 }
 
+//xerr("idx: " << idx << ", value: " << group.value() << ", stdev = " <<
+//group.stdDev());
 
+//xerr("doublingdays: " << d_doublingDays);
 
-
-
-
+// xerr("LEAVING " << d_prePeriod << ' ' << d_detectableAge);
